// 引入 spark-md5 库
importScripts('/static/js/sdk/spark-md5.min.js')

// 监听事件
console.log('子线程创建成功')

// 加载文件
function loadFile(filePath, chunkSize, onChunkRead, onFileLoaded) {
	const fileReader = new FileReader()
	const file = new File([filePath], filePath)
	let currentChunk = 0

	// 读取下一个分片
	function readChunk() {
		const start = currentChunk * chunkSize
		const end = start + chunkSize >= file.size ? file.size : start + chunkSize

		console.log(end)
		const chunkReader = new FileReader()
		chunkReader.readAsArrayBuffer(file.slice(start, end))
		chunkReader.onload = (e) => {
			onChunkRead(e.target.result)
			currentChunk++
			if (currentChunk < Math.ceil(file.size / chunkSize)) {
				readChunk()
			} else {
				onFileLoaded()
			}
		}
		chunkReader.onerror = function () {
			postMessage({
				error: '文件读取出错，请检查该文件！'
			})
		}
	}

	// 读取整个文件
	fileReader.onload = (e) => {
		readChunk()
	}
	fileReader.onerror = function () {
		postMessage({
			error: '文件读取出错，请检查该文件！'
		})
	}
	fileReader.readAsArrayBuffer(file)
}

// 计算文件 MD5
function calculateFileMD5(filePath, chunkSize) {
	const spark = new SparkMD5.ArrayBuffer()

	// 处理分片数据
	function handleChunk(chunk) {
		spark.append(chunk)
	}

	// 文件加载完成
	function fileLoaded() {
		const md5 = spark.end()
		postMessage({
			md5
		})
	}

	loadFile(filePath, chunkSize, handleChunk, fileLoaded)
}

// 启动 Worker
onmessage = (event) => {
	if (event.data.type === 'start') {
		const filePath = event.data.filePath
		const file = event.data.file
		const chunkSize = event.data.chunkSize
		// calculateFileMD5(filePath, chunkSize)
		// 使用 FileReader 读取文件内容
		const fileReader = new FileReader()
		fileReader.onload = function (e) {
			console.log(e.target.result)
		}
		fileReader.readAsArrayBuffer(file)
	}
}
